# Raincoat

MovieInfo is a tool to search specific number or keyword from a set of av and get information of videos and output json. This json is use for a discord bot or automation torrent download.

### Installation

`pip install getmovieinfo

### Requirements

- python = "^3.7"
- selenium = "^4.1.3"
- requests = "^2.27.1"
- lxml = "^4.8.0"
- argparse = "^1.4.0"
- jsons = "^1.6.1"
- secrets


### Usage

`MovieInfo --number SSIS-356

`MovieInfo --keyword 涼森れむ

#### Parameters

- --number
  - Specify a video number
- --keyword
  - SPecify a keyword
- --cache_dir
  - specify a dir to store the result json


# License

This project is licensed under the MIT License
